Test coverage report: auction.models.auctionmodel

# auction.models.auctionmodel: 5 total statements, 100.0% covered

Generated: Mon 2013-04-29 18:13 CST

Source file: /home/slam/workspace/django-auction/auction/models/auctionmodel.py

Stats: 2 executed, 0 missed, 3 excluded, 3 ignored

1. `import importlib`
2. `from django.conf import settings`
3. `from auction.utils.loader import load_class`
4. ``
5. `AUCTION_AUCTION_MODEL = getattr(settings, 'AUCTION_AUCTION_MODEL',`
6. `'auction.models.defaults.Auction')`
7. ``
8. `Auction = load_class(AUCTION_AUCTION_MODEL, 'AUCTION_AUCTION_MODEL')`